pub struct NodeSpec {
pub label: String,
pub filter: String,
pub args: Vec<String>,
}Expand description
Specification of a single node in the graph.
Fields
label: StringUnique label used to identify this node in edges.
If the DSL input did not provide an explicit label:name prefix the
label is synthesised from the filter name and an auto-increment counter
(e.g. scale_0, scale_1).
filter: StringFilter type name (the identifier before any argument list).
args: Vec<String>Positional arguments provided in the parenthesised argument list.
Implementations