pub struct TimecodeFilter { /* private fields */ }Expand description
Timecode burn-in filter.
This filter overlays timecode and metadata information onto video frames.
Implementations
Sourceimpl TimecodeFilter
impl TimecodeFilter
Sourcepub fn new(
id: NodeId,
name: impl Into<String>,
config: TimecodeConfig,
font_data: Vec<u8>,
) -> GraphResult<Self>
pub fn new( id: NodeId, name: impl Into<String>, config: TimecodeConfig, font_data: Vec<u8>, ) -> GraphResult<Self>
Create a new timecode filter with a provided font.
Errors
Returns error if the font data is invalid.
Sourcepub fn from_font_file(
id: NodeId,
name: impl Into<String>,
config: TimecodeConfig,
font_path: &str,
) -> GraphResult<Self>
pub fn from_font_file( id: NodeId, name: impl Into<String>, config: TimecodeConfig, font_path: &str, ) -> GraphResult<Self>
Load a font from a file path and create the filter.
Errors
Returns error if the font file cannot be read or is invalid.
Sourcepub fn config(&self) -> &TimecodeConfig
pub fn config(&self) -> &TimecodeConfig
Get the current configuration.
Sourcepub fn set_config(&mut self, config: TimecodeConfig)
pub fn set_config(&mut self, config: TimecodeConfig)
Update the configuration.
Sourcepub fn set_context(&mut self, context: FrameContext)
pub fn set_context(&mut self, context: FrameContext)
Update the frame context.