FrameRef

Struct FrameRef 

pub struct FrameRef { /* private fields */ }
Reference-counted frame for zero-copy passing.

When a frame needs to be shared between multiple consumers without copying, use FrameRef to wrap it in an Arc.

Implementations

Source

impl FrameRef

pub fn new(frame: FilterFrame) -> Self

Create a new frame reference.

pub fn frame(&self) -> &FilterFrame

Get a reference to the inner frame.

pub fn try_unwrap(self) -> Option<FilterFrame>

Try to get exclusive access to the frame.

Returns Some if this is the only reference, None otherwise.

pub fn ref_count(&self) -> usize

Get the reference count.

pub fn make_mut(self) -> FilterFrame

Make a copy of the frame if needed for mutation.

If this is the only reference, returns the frame directly. Otherwise, clones the frame.