pub struct PartEdge {
pub from: u64,
pub to: u64,
pub comm_cost: f64,
}Expand description
An edge between two nodes, carrying a communication cost.
Fields
from: u64Source node ID.
to: u64Destination node ID.
comm_cost: f64Communication cost if these nodes are in different partitions.
Implementations