pub struct RewriteRule {
pub id: RuleId,
pub name: String,
pub pattern: PatternKind,
pub action: RewriteAction,
pub priority: i32,
pub enabled: bool,
}Expand description
A single graph rewrite rule.
Fields
id: RuleIdUnique identifier.
name: StringHuman-readable name for this rule.
pattern: PatternKindThe pattern to match.
action: RewriteActionThe action to take on match.
priority: i32Priority (higher = applied first).
enabled: boolWhether this rule is currently enabled.
Implementations
Sourceimpl RewriteRule
impl RewriteRule
Sourcepub fn new(
id: RuleId,
name: &str,
pattern: PatternKind,
action: RewriteAction,
) -> Self
pub fn new( id: RuleId, name: &str, pattern: PatternKind, action: RewriteAction, ) -> Self
Create a new rewrite rule.
Sourcepub fn with_priority(self, priority: i32) -> Self
pub fn with_priority(self, priority: i32) -> Self
Set the priority of this rule.
Sourcepub fn set_enabled(&mut self, enabled: bool)
pub fn set_enabled(&mut self, enabled: bool)
Enable or disable this rule.
Sourcepub fn matches_node(
&self,
filter_type: &str,
properties: &HashMap<String, String>,
) -> bool
pub fn matches_node( &self, filter_type: &str, properties: &HashMap<String, String>, ) -> bool
Check whether this rule matches a given node description.
Sourcepub fn matches_chain(&self, first_type: &str, second_type: &str) -> bool
pub fn matches_chain(&self, first_type: &str, second_type: &str) -> bool
Check whether this rule matches a chain of two nodes.