pub struct GraphValidator;Expand description
Validates a GraphDescriptor and produces a GraphValidationResult.
Implementations
Sourceimpl GraphValidator
impl GraphValidator
Sourcepub fn validate(desc: &GraphDescriptor) -> GraphValidationResult
pub fn validate(desc: &GraphDescriptor) -> GraphValidationResult
Run all checks on desc and return the combined result.
Sourcepub fn cycle_count(desc: &GraphDescriptor) -> usize
pub fn cycle_count(desc: &GraphDescriptor) -> usize
Count the number of directed cycles found in desc.
Uses DFS to count strongly-connected back-edges.