pub struct PriorityNodeId(pub u64);Expand description
A unique node identifier used within the priority system.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for PriorityNodeId
impl Clone for PriorityNodeId
Sourcefn clone(&self) -> PriorityNodeId
fn clone(&self) -> PriorityNodeId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PriorityNodeId
Sourceimpl Debug for PriorityNodeId
impl Debug for PriorityNodeId
Sourceimpl Display for PriorityNodeId
impl Display for PriorityNodeId
impl Eq for PriorityNodeId
Sourceimpl Hash for PriorityNodeId
impl Hash for PriorityNodeId
Sourceimpl PartialEq for PriorityNodeId
impl PartialEq for PriorityNodeId
Sourcefn eq(&self, other: &PriorityNodeId) -> bool
fn eq(&self, other: &PriorityNodeId) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PriorityNodeId