pub struct DeadNodeEliminationPass;Expand description
Removes nodes whose outputs list is empty (i.e., no other node consumes
their output).
Nodes with no outputs are considered dead unless they are the only node in the graph (treating them as implicit sinks).
Implementations