pub enum NodeType {
Source,
Decoder,
Filter,
Encoder,
Sink,
Mixer,
Splitter,
}Expand description
Classification of a processing node.
Variants
Produces media data (e.g. file reader, camera capture).
Decoder
Decodes compressed media into raw frames.
Filter
Transforms media data (e.g. scaler, colour converter).
Encoder
Encodes raw frames into a compressed format.
Sink
Consumes media data (e.g. file writer, display).
Mixer
Combines multiple input streams into one.
Splitter
Distributes one input stream to multiple outputs.
Implementations
Sourceimpl NodeType
impl NodeType
Sourcepub fn max_inputs(&self) -> usize
pub fn max_inputs(&self) -> usize
Maximum number of input connections accepted by this node type.
Sourcepub fn max_outputs(&self) -> usize
pub fn max_outputs(&self) -> usize
Maximum number of output connections this node type can produce.