pub struct FramePool { /* private fields */ }Expand description
Frame pool for reusing frame allocations.
This is a placeholder for integration with oximedia-core’s buffer pool.
Implementations
Sourceimpl FramePool
impl FramePool
Sourcepub fn get_video_frame(
&mut self,
format: PixelFormat,
width: u32,
height: u32,
) -> VideoFrame
pub fn get_video_frame( &mut self, format: PixelFormat, width: u32, height: u32, ) -> VideoFrame
Get a video frame from the pool or create a new one.
Sourcepub fn return_video_frame(&mut self, frame: VideoFrame)
pub fn return_video_frame(&mut self, frame: VideoFrame)
Return a video frame to the pool.
Sourcepub fn get_audio_frame(
&mut self,
format: SampleFormat,
sample_rate: u32,
channels: ChannelLayout,
) -> AudioFrame
pub fn get_audio_frame( &mut self, format: SampleFormat, sample_rate: u32, channels: ChannelLayout, ) -> AudioFrame
Get an audio frame from the pool or create a new one.
Sourcepub fn return_audio_frame(&mut self, frame: AudioFrame)
pub fn return_audio_frame(&mut self, frame: AudioFrame)
Return an audio frame to the pool.
Sourcepub fn video_frame_count(&self) -> usize
pub fn video_frame_count(&self) -> usize
Get the number of video frames in the pool.
Sourcepub fn audio_frame_count(&self) -> usize
pub fn audio_frame_count(&self) -> usize
Get the number of audio frames in the pool.