pub struct FrameRef { /* private fields */ }Expand description
Reference-counted frame for zero-copy passing.
When a frame needs to be shared between multiple consumers without copying,
use FrameRef to wrap it in an Arc.
Implementations
Sourceimpl FrameRef
impl FrameRef
Sourcepub fn new(frame: FilterFrame) -> Self
pub fn new(frame: FilterFrame) -> Self
Create a new frame reference.
Sourcepub fn frame(&self) -> &FilterFrame
pub fn frame(&self) -> &FilterFrame
Get a reference to the inner frame.
Sourcepub fn try_unwrap(self) -> Option<FilterFrame>
pub fn try_unwrap(self) -> Option<FilterFrame>
Try to get exclusive access to the frame.
Returns Some if this is the only reference, None otherwise.
Sourcepub fn make_mut(self) -> FilterFrame
pub fn make_mut(self) -> FilterFrame
Make a copy of the frame if needed for mutation.
If this is the only reference, returns the frame directly. Otherwise, clones the frame.