TransientError

Trait TransientError 

pub trait TransientError {
    // Required method
    fn is_transient(&self) -> bool;
}
Marker trait for errors that are considered transient (i.e. worth retrying, such as a temporary resource contention or a momentary decode stall).

Implement this on your custom error type and return it from a node’s process function to enable automatic retry via RetryPolicy.

Required Methods

fn is_transient(&self) -> bool

Returns true when the error represents a transient condition.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors